package cz.cvut.and.tutorial04;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class Tutorial04Activity extends Activity {
	private static final int DIALOG_EXIT = 1;
	private Button mContextMenuButton;
	private Button mDialogButton;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		mContextMenuButton = (Button) findViewById(R.id.button_context_menu);
		registerForContextMenu(mContextMenuButton);

		mDialogButton = (Button) findViewById(R.id.button_dialog);
		mDialogButton.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				showDialog(DIALOG_EXIT);
			}
		});
	}

	@Override
	protected Dialog onCreateDialog(int id) {
		if (id == DIALOG_EXIT) {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setTitle(R.string.dialog_button)
					.setMessage(R.string.exit)
					.setPositiveButton(R.string.yes,
							new DialogInterface.OnClickListener() {
								@Override
								public void onClick(DialogInterface dialog,
										int which) {
									Tutorial04Activity.this.finish();
								}
							})
					.setNegativeButton(R.string.no,
							new DialogInterface.OnClickListener() {

								@Override
								public void onClick(DialogInterface dialog,
										int which) {
									dialog.dismiss();
								}
							});
			return builder.create();
		}
		return null;
	}

	@Override
	public void onCreateContextMenu(ContextMenu menu, View v,
			ContextMenuInfo menuInfo) {
		if (v.getId() == R.id.button_context_menu) {
			menu.setHeaderTitle(R.string.context_menu);
			getMenuInflater().inflate(R.menu.context_menu_for_button, menu);
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.context_menu_for_button, menu);
		return true;
	}

	@Override
	public boolean onContextItemSelected(MenuItem item) {
		return handleItemClick(item);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		return handleItemClick(item);
	}

	private boolean handleItemClick(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.menu_enable:
			mDialogButton.setEnabled(true);
			return true;
		case R.id.menu_disable:
			mDialogButton.setEnabled(false);
			return true;
		}
		return false;
	}

}
